
# Type: exon to transcript relationship_object




URI: [biolink:exon_to_transcript_relationship_object](https://w3id.org/biolink/vocab/exon_to_transcript_relationship_object)


## Domain and Range

[ExonToTranscriptRelationship](ExonToTranscriptRelationship.md) ->  <sub>REQ</sub> [Transcript](Transcript.md)

## Parents

 *  is_a: [sequence feature relationship➞object](sequence_feature_relationship_object.md)

## Children


## Used by

 * [ExonToTranscriptRelationship](ExonToTranscriptRelationship.md)
